import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleBand,
  line,
  curveBasis

} from 'd3';

const svg = select('svg');
 
const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d =>  d.States;
  const xAxisLabel = 'States'
  const yValue = d =>  d.SCs ;
  const yAxisLabel = 'SCs'
  const margin = { top: 100, right: 40, bottom: 80, left: 120 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const circleRadius = 5;
  const title = 'Percentage distribution of social groups among States, 2007-08'; 
  
  const xScale = scaleBand()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    
  
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight,0])
    .nice();
 
 
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  
 
  const xAxis = axisBottom(xScale)
    
    .tickSize(-innerHeight)
    .tickPadding(15)
   
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  g.append('g')
    .call(yAxis)
    .selectAll('.domain')
      .remove();
 
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove(); 
 
    
  xAxisG.append('text')
    .attr('class','xAxis-label')
    .text(xAxisLabel)
    .attr('fill','black')
    .attr('x',innerWidth/2)
    .attr('y',70)

     
  yAxisG.append('text')
    .attr('class','yAxis-label')
    .text(yAxisLabel)
    .attr('fill','black')
    .attr('x',-150)
    .attr('y',-50)
    .attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle');
 
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d =>  yScale(yValue(d)))
    .curve(curveBasis);
  
  g.append('path') 
    .attr('d', lineGenerator(data))
    .attr('class','line-path'); 
  
  
  g.append('text')
    .attr('class','title')
    .attr('y',-30)
    .text(title)

 
  xAxisG.selectAll("text")
    .attr("y", 0)
    .attr("x", 9)  
    .attr("dy", ".35em")
    .attr("transform", "rotate(90)")
    .style("text-anchor", "start");
  
}; 



csv('https://vizhub.com/nitanagdeote/datasets/-percentage-distribution-of-social-groups-among-states-except-uts---sheet1.csv')
  .then(data => {
    data.forEach(d => {
     d.SCs = +d.SCs; 
     d.STs = +d.STs;
     });
  render(data);
});